%
%	Examples for sparsepoly
%
%

% Setup path for sglib
addpath(genpath('sglib_subset'));

% Path to MOSEK
addpath('/home/lauer/Documents/RECHERCHE/mosek/7/toolbox/r2012a');

try 
	mosekopt('echo(0)');
catch err
	clc;
	error('MOSEK not found. Please install MOSEK and add it to the PATH.');
end

% Target vector to recover
x = [1; 1 ; 0; 0 ; 0;];

% Number of variables
n = length(x);

% Number of polynomials
N = 50;

% Max degree of the polynomials
degree = 4;

% Compute the monomials in phi_x = phi(x)
alpha = multiindex(n, degree);
M = size(alpha,1) - 1; % dimension of phi

phi_x = zeros(M,1);   
for k=1:M
	phi_x(k) = prod(x.^(alpha(k+1,:)'));  % k+1 because alpha(1,:) = 0 => constant b
end

clc;
disp('In all examples, the true x to recover is')
x
disp('======  Example 1: 50 polynomials of degree 4, no noise  ======');

	% Draw random polynomial coefficients
	Q = randn(N,M+1);
	
	% Normalize columns (polybp functions do not include precompensating weights)
	normQ = sqrt(sum(Q.^2));
	Q = Q./(ones(N,1) * normQ ); 
	
	% Compute measurements
	y = Q * [1;phi_x]; 

	% Run polynomial BP with L1-minimization
	[xhatL1, phihatL1] = polybpL1(Q, y, n, degree);

	% Run polynomial BP with Iteratively Reweighted L1/L2-minimization
	[xhatIRL1L2, phihatIRL1L2, yhatIRL1L2,sparsityIRL1L2, xhatL1L2] = polybpL1L2(Q, y, n, degree);

	% Run polynomial BP with Selective L1/L2-minimization
	[xhatSL1L2M, phihatSL1L2M] = polybpSL1L2M(Q, y, n, degree);

	% Run approximate greedy algorithm
	[xhatgreedy] = polygreedy(Q, y, n, degree);

	% Run exact greedy algorithm
	[xhatgreedyexact] = polygreedyexact(Q, y, n, degree);

	
	disp('Estimates of x:')
	disp('     L1        L1/L2    IRL1/L2   SL1/L2M   Greedy    Exact greedy');
	disp([xhatL1  xhatL1L2  xhatIRL1L2  xhatSL1L2M  xhatgreedy xhatgreedyexact])
	

disp('======  Example 2: 50 PURELY NONLINEAR polynomials of degree 4, no noise  ======');

	% Draw random polynomial coefficients
	Q = randn(N,M+1);
		
	% Normalize columns (polybp functions do not include precompensating weights)
	normQ = sqrt(sum(Q.^2));
	Q = Q./(ones(N,1) * normQ ); 
	
	% Remove linear part from the polynomials => purely nonlinear
	Q(:,1:n+1) = 0; 
	
	% Compute measurements
	y = Q * [1;phi_x]; 

	% Run polynomial BP with L1-minimization
	[xhatL1, phihatL1, yhatL1, t] = polybpL1(Q, y, n, degree);
	% Estimate support of x
	supp_xL1 = zeros(1,n); 
	for j=1:n
		idx = find(alpha(:,j) > 0)  -  1;
		if (sum(abs(phihatL1(idx))) > 1e-6)
			supp_xL1 = 1;
		end
	end
	% Estimate the values of x from estimates of the other monomials
	xhatL1 = phi2x(phihatL1, Q(:,2:end), supp_xL1, n, degree, alpha(2:end,:));		

	% Run polynomial BP with Iteratively Reweighted L1/L2-minimization
	[xhatIRL1L2, phihatIRL1L2, yhatIRL1L2,sparsityIRL1L2, xhatL1L2, phihatL1L2, sparsityL1L2] = polybpL1L2(Q, y, n, degree);
	% Estimate x from estimates of the other monomials (support(x) = find(sparsity ~= 0) )
	xhatIRL1L2 = phi2x(phihatIRL1L2, Q(:,2:end), find(sparsityIRL1L2>1e-6), n, degree, alpha(2:end,:));	
	xhatL1L2 = phi2x(phihatL1L2, Q(:,2:end), find(sparsityL1L2>1e-6), n, degree, alpha(2:end,:));	
	
	% Run polynomial BP with Selective L1/L2-minimization
	[xhatSL1L2M, phihatSL1L2M, yhatSL1L2M, sparsitySL1L2M] = polybpSL1L2M(Q, y, n, degree);
	phihatSL1L2M(1:n) = 0; % make sure phi2x() actually do something
	xhatSL1L2M = phi2x(phihatSL1L2M, Q(:,2:end), find(sparsitySL1L2M>1e-6), n, degree, alpha(2:end,:));	
	
	% Run approximate greedy algorithm
	[xhatgreedy, supp_x, err2, phihatgreedy] = polygreedy(Q, y, n, degree);
	xhatgreedy = phi2x(phihatgreedy, Q(:,2:end), supp_x, n, degree, alpha(2:end,:));
	
	% Run exact greedy algorithm
	[xhatgreedyexact, supp_xEGA, err2, phihatEGA] = polygreedyexact(Q, y, n, degree);
	xhatgreedyexact = phi2x(phihatEGA, Q(:,2:end), supp_xEGA, n, degree, alpha(2:end,:));

	
	disp('Estimates of x:')
	disp('     L1        L1/L2    IRL1/L2   SL1/L2M   Greedy    Exact greedy');
	disp([xhatL1  xhatL1L2  xhatIRL1L2  xhatSL1L2M  xhatgreedy xhatgreedyexact])
	

disp('======  Example 3: 50 polynomials of degree 4, WITH NOISE  ======');
disp('          (using functions XXnoiseL2.m )');

	% Error bound 
	epsilon = 0.3;

	% Draw random polynomial coefficients
	Q = randn(N,M+1);
	
	% Normalize columns 
	normQ = sqrt(sum(Q.^2));
	Q = Q./(ones(N,1) * normQ ); 
	
	% Compute measurements
	noise = randn(N,1); 
	y = Q * [1;phi_x]  +  0.3 * noise / norm(noise); 

	% Run polynomial BP with L1-minimization
	[xhatL1, phihatL1] = polybpL1noiseL2(Q, y, n, degree, epsilon);

	% Run polynomial BP with Iteratively Reweighted L1/L2-minimization
	[xhatIRL1L2, phihatIRL1L2, yhatIRL1L2,sparsityIRL1L2, xhatL1L2] = polybpL1L2noiseL2(Q, y, n, degree, epsilon);

	% Run polynomial BP with Selective L1/L2-minimization
	[xhatSL1L2M, phihatSL1L2M] = polybpSL1L2MnoiseL2(Q, y, n, degree, epsilon);

	% Run approximate greedy algorithm
	[xhatgreedy] = polygreedy(Q, y, n, degree, epsilon);

	% Run exact greedy algorithm
	[xhatgreedyexact] = polygreedyexact(Q, y, n, degree, epsilon);

	errors = [norm(xhatL1 - x).^2 , norm(xhatL1L2 - x).^2, norm(xhatIRL1L2 - x).^2, norm(xhatSL1L2M - x).^2, norm(xhatgreedy - x).^2, norm(xhatgreedyexact - x).^2 ];

	success = 1 - [any( ( (abs(xhatL1) > 1e-6) - (x~=0) ) ~= 0 ), 	any( ( (abs(xhatL1L2) > 1e-6) - (x~=0) ) ~= 0 ), any( ( (abs(xhatIRL1L2) > 1e-6) - (x~=0) ) ~= 0 ), any( ( (abs(xhatSL1L2M) > 1e-6) - (x~=0) ) ~= 0 ), any( ( (abs(xhatgreedy) > 1e-6) - (x~=0) ) ~= 0 ), any( ( (abs(xhatgreedyexact) > 1e-6) - (x~=0) ) ~= 0 ) ];

	disp('Estimates of x:')
	disp('     L1        L1/L2    IRL1/L2   SL1/L2M   Greedy    Exact greedy');
	disp([xhatL1  xhatL1L2  xhatIRL1L2  xhatSL1L2M  xhatgreedy xhatgreedyexact])
	
	disp('Errors ||x - xhat||^2:')
	disp('     L1        L1/L2    IRL1/L2   SL1/L2M   Greedy    Exact greedy');
	disp(errors);
	
	disp('Successful estimation of the support of x?')
	disp('    L1  L1/L2 IRL1/L2 SL1/L2M Greedy Exact greedy');
	disp(success);
	
